pkglts\.option\.travis package
==============================

Submodules
----------

pkglts\.option\.travis\.config module
-------------------------------------

.. automodule:: pkglts.option.travis.config
    :members:
    :undoc-members:
    :show-inheritance:

pkglts\.option\.travis\.handlers module
---------------------------------------

.. automodule:: pkglts.option.travis.handlers
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pkglts.option.travis
    :members:
    :undoc-members:
    :show-inheritance:
